#[non_exhaustive]pub enum Error {
Http(Box<dyn Error + Send + Sync>),
RequestBuild(String),
Parse(Box<dyn Error + Send + Sync>),
Utf8(FromUtf8Error),
Json(Error),
}Expand description
The errors that can occur during the ingestion of an
Endpoint.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Http(Box<dyn Error + Send + Sync>)
The HttpClient could not execute a request.
RequestBuild(String)
The construction of a request failed (for example, a header value that is not valid).
Parse(Box<dyn Error + Send + Sync>)
Endpoint::parse failed.
Utf8(FromUtf8Error)
A response body is not valid UTF-8.
Json(Error)
A response body is not valid JSON.
Implementations